define({ root:

//begin v1.x content
{
	"field-thu-narrow-relative+0": "this Thursday",
	"field-thu-narrow-relative+1": "next Thursday",
	"field-sun-narrow-relative+0": "this Sunday",
	"field-sun-narrow-relative+1": "next Sunday",
	"months-format-wide": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-narrow-relative+0": "this Friday",
	"field-fri-narrow-relative+1": "next Friday",
	"field-weekdayOfMonth-narrow@localeAlias162": {
		"bundle": "",
		"target": "field-weekdayOfMonth-short"
	},
	"field-wed-narrow@localeAlias174": {
		"bundle": "",
		"target": "field-wed-short"
	},
	"field-weekdayOfMonth-narrow@localeAlias163": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"field-wed-narrow@localeAlias175": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-thu-short@localeAlias176": {
		"bundle": "",
		"target": "field-thu"
	},
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"days-standAlone-abbr@localeAlias113": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-standAlone-abbr@localeAlias114": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"days-standAlone-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-weekdayOfMonth-short@localeAlias161": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "last Wednesday",
	"field-tue-short@localeAlias170": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-minute-narrow-relative+0": "this minute",
	"quarters@localeAlias119": {
		"bundle": "gregorian",
		"target": "quarters"
	},
	"days-format-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-day-narrow@localeAlias153": {
		"bundle": "",
		"target": "field-day-short"
	},
	"field-day-narrow@localeAlias154": {
		"bundle": "",
		"target": "field-day"
	},
	"field-minute-short@localeAlias191": {
		"bundle": "",
		"target": "field-minute"
	},
	"field-month-short-relative+0": "this month",
	"field-month-short-relative+1": "next month",
	"field-thu-relative+0": "this Thursday",
	"field-thu-relative+1": "next Thursday",
	"dayPeriods-format-wide-am": "AM",
	"field-fri-relative+0": "this Friday",
	"field-fri-relative+1": "next Friday",
	"dateFormatItem-yMd": "r-MM-dd",
	"dayPeriods-standAlone-narrow@localeAlias129": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"field-quarter-relative+0": "this quarter",
	"field-thu-narrow-relative+-1": "last Thursday",
	"field-quarter-relative+1": "next quarter",
	"field-sun-short-relative+0": "this Sunday",
	"timeFormat-short": "HH:mm",
	"field-sun-short-relative+1": "next Sunday",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-Md": "MM-dd",
	"field-week-narrow": "Week",
	"field-hour-relative+0": "this hour",
	"field-day-relative+-1": "yesterday",
	"field-mon-narrow-relative+-1": "last Monday",
	"field-sat-narrow@localeAlias183": {
		"bundle": "",
		"target": "field-sat-short"
	},
	"field-sat-narrow@localeAlias184": {
		"bundle": "",
		"target": "field-sat"
	},
	"dayPeriods-standAlone-narrow@localeAlias130": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-minute-narrow": "Minute",
	"dateFormatItem-yyyyMMM": "r(U) MMM",
	"field-thu-short-relative+0": "this Thursday",
	"field-mon-relative+0": "this Monday",
	"field-thu-short-relative+1": "next Thursday",
	"field-mon-relative+1": "next Monday",
	"dateTimeFormats-appendItem-Era": "{1} {0}",
	"field-day-narrow-relative+0": "today",
	"field-era-short": "Era",
	"field-day-narrow-relative+1": "tomorrow",
	"field-sat-narrow-relative+0": "this Saturday",
	"timeFormat-long": "HH:mm:ss z",
	"field-sat-narrow-relative+1": "next Saturday",
	"field-week-narrow-relative+0": "this week",
	"field-week-narrow-relative+1": "next week",
	"days-format-short@localeAlias111": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-format-short@localeAlias112": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-hour-short-relative+0": "this hour",
	"field-wed-narrow-relative+0": "this Wednesday",
	"field-wed-narrow-relative+1": "next Wednesday",
	"field-year-short@localeAlias137": {
		"bundle": "",
		"target": "field-year"
	},
	"field-month": "Month",
	"months-standAlone-wide": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"field-weekday-narrow": "Day of the Week",
	"field-mon-short@localeAlias167": {
		"bundle": "",
		"target": "field-mon"
	},
	"dayPeriods-format-narrow@localeAlias126": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"field-era-short@localeAlias134": {
		"bundle": "",
		"target": "field-era"
	},
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"field-minute-short-relative+0": "this minute",
	"dateFormatItem-hm": "h:mm a",
	"field-year-narrow": "Year",
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"dayPeriods-standAlone-abbr@localeAlias128": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"timeFormat@localeAlias133": {
		"bundle": "gregorian",
		"target": "timeFormat"
	},
	"months-standAlone-abbr@localeAlias105": {
		"bundle": "chinese",
		"target": "months-format-abbr"
	},
	"months-standAlone-abbr@localeAlias106": {
		"bundle": "chinese",
		"target": "months-format-wide"
	},
	"field-tue-short-relative+0": "this Tuesday",
	"field-tue-short-relative+1": "next Tuesday",
	"dateTimeFormats-appendItem-Year": "{1} {0}",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"field-tue-narrow-relative+0": "this Tuesday",
	"field-tue-narrow-relative+1": "next Tuesday",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-E": "ccc",
	"days-standAlone-wide@localeAlias118": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "HH",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-M": "L",
	"quarters-standAlone-wide@localeAlias124": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-wed-short-relative+0": "this Wednesday",
	"field-wed-short-relative+1": "next Wednesday",
	"field-fri-short-relative+0": "this Friday",
	"field-weekOfMonth-short": "Week Of Month",
	"field-fri-short-relative+1": "next Friday",
	"field-quarter-short-relative+-1": "last quarter",
	"field-second-short@localeAlias194": {
		"bundle": "",
		"target": "field-second"
	},
	"field-year-short-relative+-1": "last year",
	"field-tue-narrow@localeAlias171": {
		"bundle": "",
		"target": "field-tue-short"
	},
	"field-tue-narrow@localeAlias172": {
		"bundle": "",
		"target": "field-tue"
	},
	"dateFormatItem-Bhm": "h:mm B",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-medium": "{1} {0}",
	"field-quarter-narrow-relative+-1": "last quarter",
	"dateFormatItem-d": "d",
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-h": "h a",
	"quarters-standAlone-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-zone-narrow@localeAlias198": {
		"bundle": "",
		"target": "field-zone-short"
	},
	"field-wed-short@localeAlias173": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-zone-narrow@localeAlias199": {
		"bundle": "",
		"target": "field-zone"
	},
	"field-weekOfMonth-narrow": "Week Of Month",
	"field-second-narrow@localeAlias195": {
		"bundle": "",
		"target": "field-second-short"
	},
	"field-second-narrow@localeAlias196": {
		"bundle": "",
		"target": "field-second"
	},
	"dateFormatItem-yyyyQQQ": "r(U) QQQ",
	"dateFormatItem-yyyyMMMM": "r(U) MMMM",
	"dateFormatItem-y": "r(U)",
	"field-minute-relative+0": "this minute",
	"field-year-short-relative+0": "this year",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "next year",
	"field-weekday": "Day of the Week",
	"dayPeriods-format-narrow-pm": "PM",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-tue-narrow-relative+-1": "last Tuesday",
	"field-year-narrow@localeAlias138": {
		"bundle": "",
		"target": "field-year-short"
	},
	"field-year-narrow@localeAlias139": {
		"bundle": "",
		"target": "field-year"
	},
	"field-year-narrow-relative+-1": "last year",
	"dateFormatItem-yyyyMMMd": "r MMM d",
	"field-hour-short@localeAlias188": {
		"bundle": "",
		"target": "field-hour"
	},
	"field-sat-relative+-1": "last Saturday",
	"dateFormatItem-UMMM": "U MMM",
	"quarters-format-narrow@localeAlias121": {
		"bundle": "gregorian",
		"target": "quarters-standAlone-narrow"
	},
	"dayPeriods-standAlone-narrow-pm": "PM",
	"field-zone-short@localeAlias197": {
		"bundle": "",
		"target": "field-zone"
	},
	"field-mon-narrow-relative+0": "this Monday",
	"field-mon-narrow-relative+1": "next Monday",
	"field-month-narrow@localeAlias144": {
		"bundle": "",
		"target": "field-month-short"
	},
	"field-month-narrow@localeAlias145": {
		"bundle": "",
		"target": "field-month"
	},
	"days-standAlone-short@localeAlias115": {
		"bundle": "gregorian",
		"target": "days-format-short"
	},
	"field-second": "Second",
	"days-standAlone-short@localeAlias116": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"field-year-relative+-1": "last year",
	"field-weekOfMonth-short@localeAlias149": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"days-standAlone-short@localeAlias117": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-weekdayOfMonth-short": "Weekday Of Month",
	"dateFormat-short": "r-MM-dd",
	"field-second-short": "Second",
	"field-thu-short-relative+-1": "last Thursday",
	"field-zone": "Zone",
	"field-dayperiod-narrow": "Dayperiod",
	"field-sun-short-relative+-1": "last Sunday",
	"dateFormatItem-UM": "U MM",
	"field-week-short": "Week",
	"dayPeriods-standAlone-abbr-am": "AM",
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-sat-short@localeAlias182": {
		"bundle": "",
		"target": "field-sat"
	},
	"field-day-short-relative+0": "today",
	"field-dayOfYear-short": "Day Of Year",
	"field-day-short-relative+1": "tomorrow",
	"dateFormat-long": "r(U) MMMM d",
	"field-sun-narrow-relative+-1": "last Sunday",
	"days-format-abbr@localeAlias109": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"months-standAlone-wide@localeAlias107": {
		"bundle": "chinese",
		"target": "months-format-wide"
	},
	"field-second-relative+0": "now",
	"field-quarter-relative+-1": "last quarter",
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-day-short@localeAlias152": {
		"bundle": "",
		"target": "field-day"
	},
	"field-month-short@localeAlias143": {
		"bundle": "",
		"target": "field-month"
	},
	"field-week-relative+-1": "last week",
	"field-month-relative+-1": "last month",
	"months-format-abbr@localeAlias103": {
		"bundle": "chinese",
		"target": "months-format-wide"
	},
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year": "Year",
	"field-era": "Era",
	"field-dayOfYear-narrow@localeAlias156": {
		"bundle": "",
		"target": "field-dayOfYear-short"
	},
	"field-weekday-short@localeAlias158": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-dayOfYear-narrow@localeAlias157": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"days-standAlone-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-mon-narrow@localeAlias168": {
		"bundle": "",
		"target": "field-mon-short"
	},
	"field-mon-narrow@localeAlias169": {
		"bundle": "",
		"target": "field-mon"
	},
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dateFormatItem-UMMMd": "U MMM d",
	"field-day-short-relative+-1": "yesterday",
	"dateFormatItem-GyMMM": "r(U) MMM",
	"days-format-narrow@localeAlias110": {
		"bundle": "gregorian",
		"target": "days-standAlone-narrow"
	},
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-sun-narrow@localeAlias165": {
		"bundle": "",
		"target": "field-sun-short"
	},
	"field-sun-narrow@localeAlias166": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-hour": "Hour",
	"field-dayOfYear-narrow": "Day Of Year",
	"field-second-narrow-relative+0": "now",
	"field-quarter": "Quarter",
	"field-month-narrow-relative+0": "this month",
	"field-month-narrow-relative+1": "next month",
	"dayPeriods@localeAlias125": {
		"bundle": "gregorian",
		"target": "dayPeriods"
	},
	"dateFormatItem-yyyy": "r(U)",
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"field-day": "Day",
	"field-mon-relative+-1": "last Monday",
	"field-dayOfYear": "Day Of Year",
	"dateFormat-medium": "r MMM d",
	"dateTimeFormat-short": "{1} {0}",
	"field-weekday-narrow@localeAlias159": {
		"bundle": "",
		"target": "field-weekday-short"
	},
	"dateFormatItem-GyMMMd": "r MMM d",
	"dateFormatItem-MEd": "MM-dd, E",
	"field-tue-short-relative+-1": "last Tuesday",
	"field-year-short": "Year",
	"field-week-narrow@localeAlias147": {
		"bundle": "",
		"target": "field-week-short"
	},
	"field-week-narrow@localeAlias148": {
		"bundle": "",
		"target": "field-week"
	},
	"field-month-short": "Month",
	"field-era-narrow@localeAlias135": {
		"bundle": "",
		"target": "field-era-short"
	},
	"field-era-narrow@localeAlias136": {
		"bundle": "",
		"target": "field-era"
	},
	"dateFormatItem-MMMEd": "MMM d, E",
	"dateFormatItem-MMMd": "MMM d",
	"field-weekday-narrow@localeAlias160": {
		"bundle": "",
		"target": "field-weekday"
	},
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"dayPeriods-format-abbr-am": "AM",
	"field-fri-short@localeAlias179": {
		"bundle": "",
		"target": "field-fri"
	},
	"field-sat-relative+0": "this Saturday",
	"dayPeriods-format-wide-pm": "PM",
	"field-sat-relative+1": "next Saturday",
	"field-hour-narrow@localeAlias189": {
		"bundle": "",
		"target": "field-hour-short"
	},
	"months-format-narrow@localeAlias104": {
		"bundle": "chinese",
		"target": "months-standAlone-narrow"
	},
	"days-standAlone-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-zone-short": "Zone",
	"field-week-short-relative+0": "this week",
	"field-week-short-relative+1": "next week",
	"dateFormatItem-yyyyMMMEd": "r(U) MMM d, E",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-fri-short-relative+-1": "last Friday",
	"field-month-narrow": "Month",
	"dayPeriods-format-narrow-am": "AM",
	"field-thu-narrow@localeAlias177": {
		"bundle": "",
		"target": "field-thu-short"
	},
	"field-month-narrow-relative+-1": "last month",
	"field-thu-narrow@localeAlias178": {
		"bundle": "",
		"target": "field-thu"
	},
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-hour-narrow@localeAlias190": {
		"bundle": "",
		"target": "field-hour"
	},
	"field-weekday-short": "Day of the Week",
	"field-day-narrow-relative+-1": "yesterday",
	"field-quarter-short": "Quarter",
	"days-format-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-dayperiod-narrow@localeAlias186": {
		"bundle": "",
		"target": "field-dayperiod-short"
	},
	"field-dayperiod-narrow@localeAlias187": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"quarters-standAlone-abbr@localeAlias122": {
		"bundle": "gregorian",
		"target": "quarters-format-abbr"
	},
	"field-weekOfMonth-narrow@localeAlias150": {
		"bundle": "",
		"target": "field-weekOfMonth-short"
	},
	"quarters-standAlone-abbr@localeAlias123": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"field-weekOfMonth-narrow@localeAlias151": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"field-quarter-narrow": "Quarter",
	"field-mon-short-relative+0": "this Monday",
	"field-mon-short-relative+1": "next Monday",
	"field-dayperiod-short": "Dayperiod",
	"dayPeriods-standAlone-narrow-am": "AM",
	"days@localeAlias108": {
		"bundle": "gregorian",
		"target": "days"
	},
	"field-week-narrow-relative+-1": "last week",
	"field-thu-relative+-1": "last Thursday",
	"field-mon-short-relative+-1": "last Monday",
	"field-fri-narrow-relative+-1": "last Friday",
	"field-dayperiod-short@localeAlias185": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"timeFormat-medium": "HH:mm:ss",
	"dayPeriods-standAlone-wide@localeAlias131": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-wide@localeAlias132": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-quarter-short-relative+0": "this quarter",
	"field-quarter-short-relative+1": "next quarter",
	"field-week-short@localeAlias146": {
		"bundle": "",
		"target": "field-week"
	},
	"dateFormatItem-Ed": "d, E",
	"field-wed-relative+-1": "last Wednesday",
	"field-weekOfMonth": "Week Of Month",
	"field-weekdayOfMonth-narrow": "Weekday Of Month",
	"dayPeriods-standAlone-wide-am": "AM",
	"field-fri-relative+-1": "last Friday",
	"field-minute": "Minute",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-second-short-relative+0": "now",
	"quarters-format-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-day-short": "Day",
	"field-dayperiod": "Dayperiod",
	"field-hour-short": "Hour",
	"field-fri-narrow@localeAlias180": {
		"bundle": "",
		"target": "field-fri-short"
	},
	"field-fri-narrow@localeAlias181": {
		"bundle": "",
		"target": "field-fri"
	},
	"months-standAlone-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"field-month-relative+0": "this month",
	"field-second-narrow": "Second",
	"field-month-relative+1": "next month",
	"dateFormat-full": "r(U) MMMM d, EEEE",
	"dateFormatItem-yyyyMEd": "r-MM-dd, E",
	"field-era-narrow": "Era",
	"field-sat-short-relative+-1": "last Saturday",
	"quarters-format-abbr@localeAlias120": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-week-short-relative+-1": "last week",
	"dateTimeFormat-long": "{1} {0}",
	"field-sun-relative+-1": "last Sunday",
	"field-wed-short-relative+-1": "last Wednesday",
	"dateFormatItem-yyyyQQQQ": "r(U) QQQQ",
	"field-weekdayOfMonth": "Weekday Of Month",
	"dateFormatItem-yyyyMd": "r-MM-dd",
	"field-quarter-narrow-relative+0": "this quarter",
	"dateFormatItem-GyMMMEd": "r(U) MMM d, E",
	"field-quarter-narrow-relative+1": "next quarter",
	"field-sat-short-relative+0": "this Saturday",
	"field-sat-short-relative+1": "next Saturday",
	"field-hour-narrow": "Hour",
	"field-year-narrow-relative+0": "this year",
	"field-year-narrow-relative+1": "next year",
	"dateFormatItem-Gy": "r U",
	"field-minute-narrow@localeAlias192": {
		"bundle": "",
		"target": "field-minute-short"
	},
	"field-minute-narrow@localeAlias193": {
		"bundle": "",
		"target": "field-minute"
	},
	"field-zone-narrow": "Zone",
	"dateFormatItem-yyyyM": "r-MM",
	"field-tue-relative+-1": "last Tuesday",
	"field-minute-short": "Minute",
	"field-sun-short@localeAlias164": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-quarter-short@localeAlias140": {
		"bundle": "",
		"target": "field-quarter"
	},
	"dateFormatItem-Hm": "HH:mm",
	"field-week-relative+0": "this week",
	"field-week-relative+1": "next week",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"dayPeriods-format-wide@localeAlias127": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-dayOfYear-short@localeAlias155": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-sat-narrow-relative+-1": "last Saturday",
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-quarter-narrow@localeAlias141": {
		"bundle": "",
		"target": "field-quarter-short"
	},
	"field-quarter-narrow@localeAlias142": {
		"bundle": "",
		"target": "field-quarter"
	},
	"field-month-short-relative+-1": "last month",
	"dateFormatItem-MMMMd": "MMMM d",
	"field-week": "Week",
	"dateFormatItem-UMd": "U MM-d",
	"field-day-narrow": "Day",
	"field-hour-narrow-relative+0": "this hour"
}
//end v1.x content
,
	"bs": true,
	"ca": true,
	"cs": true,
	"de": true,
	"en": true,
	"en-au": true,
	"en-ca": true,
	"es": true,
	"fi": true,
	"fr": true,
	"hr": true,
	"hu": true,
	"id": true,
	"it": true,
	"ja": true,
	"ko": true,
	"nb": true,
	"nl": true,
	"pl": true,
	"pt": true,
	"pt-pt": true,
	"ro": true,
	"ru": true,
	"sv": true,
	"th": true,
	"zh": true,
	"zh-hant": true
});